function [Dens] = ImportGROWTHMod(modfilename)
%ImportGROWTHMod: Imports data from mod.dat and mat.dat model files 
%                 generated by GROWTH
%
% Inputs: modfilename = (string) full filename of mod.dat file (ex, 'mod.dat')
%
% Outputs: Dens = Matlab structure of model data with the following fields:
%                  X = center X coord of model cell
%                  Y = center Y coord
%                  Zs = center Z coord
%                  dens = density
%                  Zt = top Z coord
%                  Zb = bottom Z coord
%                  Xl = cell length in x direction
%                  Yl = cell length in y direction
%                 Coordinates UTM, distances in m, density in kg/m^3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Written by Patricia M., April 28, 2020
% Major edits log:
% None yet!
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% import data from mod.dat file
mfid=fopen(modfilename,'r');
mparam=fscanf(mfid,'%f',16);
numcell=mparam(1);
mdata=fscanf(mfid,'%f',[7 numcell])';
fclose(mfid);

%scale data
sclfact=mparam(2);
meanx=mparam(3);
meany=mparam(4);
meanz=mparam(5);

mdata=[sclfact*mdata(:,1:6)+repmat([meanx meany 0 0 meanz meanz],numcell,1) mdata(:,7)];

%put stuff in output structure
Dens.X=mdata(:,1);
Dens.Y=mdata(:,2);
Dens.Zs=mean(mdata(:,5:6),2);
Dens.dens=mdata(:,7);
Dens.Zt=mdata(:,5);
Dens.Zb=mdata(:,6);
Dens.Xl=mdata(:,3);
Dens.Yl=mdata(:,4);

end